==> org.eclipse.scout.sdk.ui.source_3.7.2.201202140505.jar: org/eclipse/scout/sdk/ui/wizard/form/fields/buttonfield/CancelButtonNewWizard.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.wizard.form.fields.buttonfield;

import org.eclipse.jdt.core.IType;
import org.eclipse.scout.nls.sdk.model.INlsEntry;
import org.eclipse.scout.nls.sdk.model.workspace.project.INlsProject;
import org.eclipse.scout.sdk.RuntimeClasses;
import org.eclipse.scout.sdk.ScoutSdk;
import org.eclipse.scout.sdk.ui.fields.proposal.NlsProposal;

public class CancelButtonNewWizard extends ButtonFieldNewWizard {

  public CancelButtonNewWizard() {
    setWindowTitle("New Cancel Button");
  }

  @Override
  public void initWizard(IType declaringType) {
    super.initWizard(declaringType);
    getButtonFieldWizardPage().setSuperType(ScoutSdk.getType(RuntimeClasses.AbstractCancelButton));
    NlsProposal newProposal = null;
    INlsProject nlsProject = ScoutSdk.getScoutWorkspace().getScoutBundle(declaringType.getJavaProject().getProject()).findBestMatchNlsProject();
    if (nlsProject != null) {
      INlsEntry entry = nlsProject.getEntry("Cancel");
      newProposal = new NlsProposal(entry, nlsProject.getDevelopmentLanguage());
      getButtonFieldWizardPage().setTypeName("CancelButton");
    }
    getButtonFieldWizardPage().setNlsName(newProposal);
  }

}

==> org.eclipse.scout.sdk.ui.source_3.9.1.20130909-1322.jar: org/eclipse/scout/sdk/ui/wizard/form/fields/buttonfield/CancelButtonNewWizard.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.sdk.ui.wizard.form.fields.buttonfield;

import org.eclipse.jdt.core.IType;
import org.eclipse.scout.nls.sdk.model.INlsEntry;
import org.eclipse.scout.nls.sdk.model.workspace.project.INlsProject;
import org.eclipse.scout.sdk.Texts;
import org.eclipse.scout.sdk.extensions.runtime.classes.RuntimeClasses;
import org.eclipse.scout.sdk.workspace.type.ScoutTypeUtility;

public class CancelButtonNewWizard extends ButtonFieldNewWizard {

  public CancelButtonNewWizard() {
    setWindowTitle(Texts.get("NewCancelButton"));
  }

  @Override
  public void initWizard(IType declaringType) {
    super.initWizard(declaringType);
    getButtonFieldWizardPage().setSuperType(RuntimeClasses.getSuperType(RuntimeClasses.AbstractCancelButton, declaringType.getJavaProject()));
    INlsProject nlsProject = ScoutTypeUtility.getScoutBundle(declaringType.getJavaProject()).getNlsProject();
    INlsEntry entry = null;
    if (nlsProject != null) {
      entry = nlsProject.getEntry("Cancel");
      getButtonFieldWizardPage().setTypeName("CancelButton");
    }
    getButtonFieldWizardPage().setNlsName(entry);
  }

}
